@@ -1,16 +1,19 @@
 import json
 import logging
 import os
+import pathlib
 import platform
 import pprint
 import re
 import subprocess
 import tempfile
+import zipfile
 from time import sleep
 from typing import Dict, List, Optional, Tuple
 from urllib.parse import urlparse, urlunparse
 
 import click
+import requests
 import yaml
 
 import gantry
@@ -434,8 +437,11 @@ def update(projection_dir, dry_run):
     upload_url, s3_key = resp["upload_url"], resp["s3_key"]
 
     click.secho("Upload new definition...", nl=False, fg="cyan")
-    zip_file = "function.zip"
-    uploaded, err_msg = _upload_function_zip(zip_file, projection_dir, upload_url)
+    with tempfile.TemporaryDirectory() as tmpdirname:
+        uploaded, err_msg = _upload_function_zip(
+            os.path.join(tmpdirname, "function.zip"), projection_dir, upload_url
+        )
+
     if not uploaded:
         click.secho("FAILED.", fg="red")
         raise click.ClickException(f"Fail to upload new projection definition: {err_msg}")
@@ -446,7 +452,8 @@ def update(projection_dir, dry_run):
     if not request_sent:
         click.secho("FAILED.", fg="red")
         raise click.ClickException(f"Request to build custom projection failed: {err_msg}")
-    click.secho(f"SUCCESS. Task {task_id} has been submitted.", fg="cyan")
+    click.secho("SUCCESS", fg="cyan")
+    click.secho(f"--> Task {task_id} has been submitted.")
 
     click.secho("Check build progress...", nl=False, fg="cyan")
 
@@ -467,14 +474,17 @@ def _call_get_logs(api_client: APIClient, task_id: str):
     while i < max_attempts and status in PENDING_TASK_STATUSES:
         new_status, logs = _get_logs(api_client, task_id)
         if status == new_status:
-            click.secho(".", nl=False, fg="cyan")
+            click.secho(".", nl=False)
         else:
             status = new_status
+            click.secho("")
             if "FAILED" in status:
-                click.secho(status, fg="red")
+                click.secho(f"--> {status}", nl=False, fg="red")
             else:
-                click.secho(status, nl=False, fg="cyan")
+                click.secho(f"--> {status}", nl=False)
             if logs:
+                click.secho("")
+                click.secho("Build logs:", fg="cyan")
                 click.secho(logs)
 
         i += 1
@@ -491,16 +501,31 @@ def _upload_function_zip(
     if not zipped:
         return False, err_msg
 
-    proc = subprocess.run(["curl", "--upload-file", zip_file, presigned_url])
-    if proc.returncode != 0:
+    resp = requests.put(presigned_url, files={"file": open(zip_file, "rb")})
+
+    if resp.status_code != 200:
+        click.secho(resp.text)
         return False, "Failed to upload custom projection function"
     return True, ""
 
 
 def _zip_function(projection_dir: str, zip_file: str) -> Tuple[bool, str]:
-    proc = subprocess.run(["zip", "-qrj", zip_file, projection_dir])
-    if proc.returncode != 0:
-        return False, f"Failed to zip files under {projection_dir}"
+    with zipfile.ZipFile(zip_file, "w", zipfile.ZIP_DEFLATED) as zipf:
+        for root, dirs, files in os.walk(projection_dir):
+            for file in files:
+                filepath = os.path.join(root, file)
+
+                relpath = os.path.relpath(filepath, projection_dir)
+
+                # if this file is part of the extra_deps directory
+                # move it up and out of the extra_deps directory
+                # by removing the first part of the path
+                relpath_path = pathlib.Path(relpath)
+                if relpath_path.parts[0] == "extra_deps":
+                    relpath = str(pathlib.Path(*relpath_path.parts[1:]))
+
+                zipf.write(filepath, relpath)
+
     return True, ""
 
 
