@@ -188,7 +188,7 @@ class Gantry:
 
     def _handle_upload(
         self, data_batch_iterator: Iterable, data_link: DataLink, object_size: int, filename: str
-    ):
+    ) -> str:
         # Calculate part counts and generate presigned s3 urls.
         total_num_parts = math.ceil(object_size / CHUNK_SIZE)
 
@@ -242,24 +242,26 @@ class Gantry:
         batch_id = complete_res["batch_id"]
         _batch_success_msg(batch_id, data_link.application, self.log_store)
 
+        return batch_id
+
     @_log_exception
     @typechecked
     def log_records(
         self,
         application: str,
         version: Optional[Union[int, str]] = None,
-        inputs: Optional[Union[List[dict], pd.DataFrame]] = None,
-        outputs: Optional[Union[List[Any], List[dict], pd.DataFrame]] = None,
+        inputs: Optional[Union[List[dict], pd.DataFrame, pd.Series]] = None,
+        outputs: Optional[Union[List[Any], List[dict], pd.DataFrame, pd.Series]] = None,
         feedback_keys: Optional[List[str]] = None,
         feedback_ids: Optional[Union[List[str], List[dict]]] = None,
-        feedbacks: Optional[Union[List[dict], pd.DataFrame]] = None,
+        feedbacks: Optional[Union[List[dict], pd.DataFrame, pd.Series]] = None,
         ignore_inputs: Optional[List[str]] = None,
         timestamps: Optional[Union[List[datetime.datetime], pd.DatetimeIndex]] = None,
         sort_on_timestamp: bool = True,
         sample_rate: float = 1.0,
         as_batch: bool = False,
         tags: Optional[Dict[str, str]] = None,
-    ) -> None:
+    ) -> Optional[str]:
         """
         Function to record a batch of events containing predictions (inputs and outputs),
         feedback, or both simultaneously.
@@ -330,7 +332,18 @@ class Gantry:
                 tag like this tags = {"env": "environment1"} if not assigned we will use Gantry
                 client's environment value as the default environment.
 
+        Returns:
+            (str) batch_id: The id of the logged batch. Returns None if the records are not to
+                be logged as a batch
+
         """
+        if inputs is not None and isinstance(inputs, pd.Series):
+            inputs = inputs.to_frame()
+        if outputs is not None and isinstance(outputs, pd.Series):
+            outputs = outputs.to_frame()
+        if feedbacks is not None and isinstance(feedbacks, pd.Series):
+            feedbacks = feedbacks.to_frame()
+
         some_preds_exist = _is_not_empty(inputs) or _is_not_empty(outputs)
         preds_exist = _is_not_empty(inputs) and _is_not_empty(outputs)
         feedbacks_exist = _is_not_empty(feedbacks)
@@ -386,6 +399,8 @@ class Gantry:
         else:
             logger.error("Tried to log_records without prediction and without feedback")
 
+        return None
+
     @_log_exception
     def ping(self) -> bool:
         """
@@ -403,7 +418,7 @@ class Gantry:
     @_log_exception
     def ready(self) -> bool:
         """
-        Checks if API is ready to receive traffic.
+        Checks if the configured API key authenticates with the API.
         Returns True if ready, False otherwise.
         """
         return self.log_store.ready()
@@ -423,8 +438,9 @@ class Gantry:
         sample_rate: float = 1.0,
         as_batch: bool = False,
         tags: Optional[Dict[str, str]] = None,
-    ) -> None:
+    ) -> Optional[str]:
         """Internal method to log batch of predictions AND feedbacks"""
+
         if any(_is_empty(d) for d in [inputs, outputs, feedbacks]):
             raise GantryLoggingException(
                 "In order to use log_records method, inputs/outputs/feedbacks need to be provided"
@@ -472,7 +488,7 @@ class Gantry:
 
         if events:
             if as_batch:
-                self._upload_data_as_batch(
+                return self._upload_data_as_batch(
                     application, environment, version, events, BatchType.RECORD
                 )
             else:
@@ -480,6 +496,8 @@ class Gantry:
         else:
             logger.info("No events to log")
 
+        return None
+
     @_log_exception
     @typechecked
     def log_record(
@@ -730,7 +748,7 @@ class Gantry:
         sample_rate: float = 1.0,
         as_batch: bool = False,
         tags: Optional[Dict[str, str]] = None,
-    ):
+    ) -> Optional[str]:
         """
         DEPRECATION WARNING:
         This method will be deprecated soon. Please use `log_records` instead.
@@ -801,7 +819,7 @@ class Gantry:
 
                 if events:
                     if as_batch:
-                        self._upload_data_as_batch(
+                        return self._upload_data_as_batch(
                             application, environment, serialized_version, events, BatchType.FEEDBACK
                         )
                     else:
@@ -819,6 +837,8 @@ class Gantry:
 
             raise e
 
+        return None
+
     @_log_exception
     @typechecked
     def log_prediction_event(
@@ -924,7 +944,7 @@ class Gantry:
         sample_rate: float = 1.0,
         as_batch: bool = False,
         tags: Optional[Dict[str, str]] = None,
-    ):
+    ) -> Optional[str]:
         """
         DEPRECATION WARNING:
         This method will be deprecated soon. Please use `log_records` instead.
@@ -996,7 +1016,7 @@ class Gantry:
 
                 if events:
                     if as_batch:
-                        self._upload_data_as_batch(
+                        return self._upload_data_as_batch(
                             application, environment, version, events, BatchType.PREDICTION
                         )
                     else:
@@ -1012,6 +1032,8 @@ class Gantry:
 
             raise e
 
+        return None
+
     def _upload_data_as_batch(
         self,
         application: str,
@@ -1019,7 +1041,7 @@ class Gantry:
         version: Optional[Union[str, int]],
         events: List,
         batch_type: BatchType,
-    ):
+    ) -> str:
         data_link: DataLink = _build_data_link(
             application,
             environment=environment,
@@ -1031,7 +1053,7 @@ class Gantry:
         batch_count = int(
             CHUNK_SIZE / (events_bytesize / data_link.num_events)
         )  # max file chunk size / average event size -> count of batch events to get to chunk.
-        self._handle_upload(
+        return self._handle_upload(
             _build_batch_iterator(events, batch_count),
             data_link,
             events_bytesize,
