@@ -2,22 +2,10 @@ import functools
 from datetime import datetime
 from inspect import getcallargs, getfullargspec
 from typing import Dict, Optional, Tuple, Union, cast
-
 import dateparser
 import isodate
 import pandas as pd
-
 from gantry.api_client import APIClient
-from gantry.exceptions import GantryException
-from gantry.query.core.constants import GENERIC_MESSAGE, OK_STATUS, STATUS_PARAM
-
-
-def check_response(response, msg: Optional[str] = None) -> None:
-    if response.get(STATUS_PARAM) != OK_STATUS:
-        # msg has priority, then response['error'] and finally
-        # the generic error msg
-        msg = msg or response.get("error") or GENERIC_MESSAGE
-        raise GantryException(msg)
 
 
 def same_size(*params):
@@ -76,9 +64,11 @@ def get_application_views(
     )
 
     response = api_client.request(
-        "GET", "/api/v1/applications/" + application + "/views", params={"version": version_param}
+        "GET",
+        "/api/v1/applications/" + application + "/views",
+        params={"version": version_param},
+        raise_for_status=True,
     )
-    check_response(response)
 
     views = response["data"]
 
@@ -100,9 +90,8 @@ def get_last_application_version(
     if end_time:
         query_params["end_time"] = end_time
     metadata_response = api_client.request(
-        "GET", "/api/v1/models/" + application + "/schemas", query_params
+        "GET", "/api/v1/models/" + application + "/schemas", query_params, raise_for_status=True
     )
-    check_response(metadata_response)
     if metadata_response.get("data", {}).get("version") is None:
         raise RuntimeError("Unkown error: couldn't fetch last application version from API.")
 
@@ -125,9 +114,8 @@ def get_application_node_id(
         query_params["version"] = version
 
     metadata_response = api_client.request(
-        "GET", "/api/v1/models/" + application + "/schemas", query_params
+        "GET", "/api/v1/models/" + application + "/schemas", query_params, raise_for_status=True
     )
-    check_response(metadata_response)
     if metadata_response.get("data", {}).get("id") is None:
         raise RuntimeError("Unkown error: couldn't fetch node id from API.")
 
