@@ -1,13 +1,18 @@
+import base64
 import collections
 import collections.abc
 import datetime
 import hashlib
 import json
 import logging
+import os
+import pprint
 import re
 import sys
-from typing import Any, Dict, List, Optional, Tuple
+from pathlib import Path
+from typing import Any, Dict, List, Optional, Set, Tuple
 
+import requests
 from dateutil import parser
 
 from gantry.serializers import EventEncoder
@@ -170,3 +175,97 @@ def obj_by_id(els):
         obj[el.id] = el
 
     return obj
+
+
+def download_file_from_url(presigned_url: str, local_path: Path):
+    """
+    Args:
+        presigned_url (str): presigned url
+        local_path (Path): local file path
+    """
+    os.makedirs(local_path.parent, exist_ok=True)
+    with requests.get(presigned_url, stream=True) as r:
+        r.raise_for_status()
+        with local_path.open("wb") as f:
+            for chunk in r.iter_content(chunk_size=8192):
+                f.write(chunk)
+    return local_path
+
+
+def upload_file_to_url(presigned_url: str, local_path: Path):
+    """
+    Args:
+        presigned_url (str): presigned url
+        local_path (Path): local file path
+
+    Returns:
+        s3 object version id
+    """
+    res = requests.put(presigned_url, data=local_path.read_bytes())
+    res.raise_for_status()
+    return res.headers["x-amz-version-id"]
+
+
+def list_all_files(dirpath):
+    """
+    List all files in a folder
+
+    Args:
+        dirpath (Path): _description_
+
+    Returns:
+        List[Path]
+    """
+    assert dirpath.is_dir()
+    file_list = []
+    for x in dirpath.iterdir():
+        if x.is_file():
+            file_list.append(x)
+        elif x.is_dir():
+            file_list.extend(list_all_files(x))
+
+    return file_list
+
+
+def get_s3_sha256_checksum(data_bytes):
+    """
+    Generate local file base64 encoded sha256 checksum
+
+    Args:
+        data_bytes : byte data which need to be hashed
+
+    Returns:
+        sha256: base64 encoded sha256 value
+    """
+    return base64.b64encode(hashlib.sha256(data_bytes).digest()).decode("utf-8")
+
+
+def get_files_checksum(path):
+    """_summary_
+
+    Args:
+        path (_type_): Path Path("/Users/hao/workspace/raw_dataset/")
+
+    Returns:
+        {file name: sha256 checksum}
+    """
+
+    file_list = list_all_files(path)
+    return dict(
+        [(str(f.relative_to(path)), get_s3_sha256_checksum(f.read_bytes())) for f in file_list]
+    )
+
+
+def pprint_records(records: List[Dict[str, str]], include_keys: Optional[Set[str]] = None):
+    """
+    Args:
+        records (List[Dict[str, str]]): _description_
+        include_keys (Optional[Set[str]], optional): _description_. Defaults to None.
+    """
+    pp = pprint.PrettyPrinter(depth=4)
+    if not include_keys:
+        pp.pprint(records)
+    else:
+        pp.pprint(
+            [dict([(k, v) for k, v in record.items() if k in include_keys]) for record in records]
+        )
