@@ -1757,14 +1757,16 @@ def test_log_predictions_as_batch(
 @pytest.mark.parametrize("version", ["0", 0, None])
 @pytest.mark.parametrize("sort", [True, False])
 @pytest.mark.parametrize("method", ["log_feedback", "log_records_feedback"])
+@pytest.mark.parametrize("feedback_id", [{"value": "foo"}, "foo"])
 @mock.patch("gantry.logger.event_builder.uuid.uuid4")
 @mock.patch("gantry.logger.client._batch_success_msg")
 def test_log_feedback_as_batch(
-    mock_batch_success, mock_uuid, version, sort, method, init_gantry_with_api
+    mock_batch_success, mock_uuid, version, sort, method, init_gantry_with_api, feedback_id
 ):
     size = 2
     mock_uuid.side_effect = [str(x) for x in range(size + 1)]
     feedbacks = [{"value": "foo"} for _ in range(size)]
+    feedback_ids = [feedback_id for _ in range(size)]
 
     with responses.RequestsMock() as resp:
         resp.add(
@@ -1792,7 +1794,7 @@ def test_log_feedback_as_batch(
         if method == "log_feedback":
             rv = init_gantry_with_api.log_feedback(
                 application="simple_test",
-                feedback_ids=feedbacks,
+                feedback_ids=feedback_ids,
                 feedbacks=feedbacks,
                 feedback_version=version,
                 sort_on_timestamp=sort,
@@ -1804,7 +1806,7 @@ def test_log_feedback_as_batch(
             rv = init_gantry_with_api.log_records(
                 "simple_test",
                 version,
-                feedback_ids=feedbacks,
+                feedback_ids=feedback_ids,
                 feedbacks=feedbacks,
                 sort_on_timestamp=sort,
                 as_batch=True,
