@@ -4,18 +4,18 @@ import uuid
 
 import mock
 import pytest
-import responses
 import requests
+import responses
 from mock import patch
 from responses import matchers
 
 from gantry.logger.consumer import BatchConsumer
 from gantry.logger.stores import (
+    BATCH_UPLOAD_MAX_TRIES,
     APILogStore,
     _batch_iterator_factory,
-    BATCH_UPLOAD_MAX_TRIES,
-    backoff_retry_handler,
     backoff_giveup_handler,
+    backoff_retry_handler,
 )
 from gantry.serializers import EventEncoder
 
@@ -54,7 +54,7 @@ def test_batch_factory_error(batch_size):
         _ = _batch_iterator_factory([1, 2, 3], batch_size)
 
 
-@pytest.mark.parametrize("status_code", [200, 400, 404, 500])
+@pytest.mark.parametrize("status_code", [400, 404, 500])
 def test_ping_fail(status_code):
     store = APILogStore(TEST_HOST)
     with responses.RequestsMock() as rsps:
@@ -75,7 +75,7 @@ def test_ping_success(status_code):
         assert store.ping() is True
 
 
-@pytest.mark.parametrize("status_code", [200, 400, 401, 404, 500])
+@pytest.mark.parametrize("status_code", [400, 401, 404, 500])
 def test_ready_fail(status_code):
     store = APILogStore(TEST_HOST)
     with responses.RequestsMock() as rsps:
